normalize_plates: Normalize replicates

Description Usage Arguments Value Examples

View source: R/normalize_plates.R

Description

Normalize replicates

Usage

1
2
normalize_plates(df, plate.var = Plate, src.var = Luminescence,
  dst.var = Normalized)

Arguments

df

The data frame to normalize.

plate.var

The variable that delimits plates (default: Plate).

src.var

The variable to normalize (default: Luminescence).

dst.var

The variable in which to store the normalized result (default: Normalized).

...

Unused additional arguments, necessary for the correctness of the function signature.

Value

The data frame with each Plate's values normalized by the average of that Plate's standards and placed in Normalized.

Examples

1

Aehmlo/lucy documentation built on Oct. 30, 2019, 4:09 a.m.