summarize_plates: Summarize results

Description Usage Arguments Details Value Examples

View source: R/summarize_plates.R

Description

Each Formulation will be summarized and given a mean, an se, and an n column.

Usage

1
summarize_plates(df, src.var = Normalized)

Arguments

df

The data frame to summarize.

src.var

The variable to be summarized (default: Normalized).

Details

This should be the terminal step of analysis (which is why it removes other independent variables).

Value

A summary of the data frame, with mean, se, and n columns added based on src.var.

Examples

1
2

Aehmlo/lucy documentation built on Oct. 30, 2019, 4:09 a.m.