Description Usage Arguments Value Examples
View source: R/normalize_plates.R
Normalize replicates
1 2 | normalize_plates(df, plate.var = Plate, src.var = Luminescence,
dst.var = Normalized)
|
df |
The data frame to normalize. |
plate.var |
The variable that delimits plates (default: |
src.var |
The variable to normalize (default: |
dst.var |
The variable in which to store the normalized result (default: |
... |
Unused additional arguments, necessary for the correctness of the function signature. |
The data frame with each Plate's values normalized by the average of that Plate's standards and placed in Normalized.
1 | normalize_plates(some.df)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.