Description Usage Arguments Details Value Examples
View source: R/summarize_plates.R
Each Formulation will be summarized and given a mean, an se, and an n column.
1 | summarize_plates(df, src.var = Normalized)
|
df |
The data frame to summarize. |
src.var |
The variable to be summarized (default: |
This should be the terminal step of analysis (which is why it removes other independent variables).
A summary of the data frame, with mean, se, and n columns added based on src.var.
1 2 | some.df %>% normalize_plates %>% summarize_plates
some.df %>% pool_plates %>% normalize_plates %>% summarize_plates
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.